@@ -1,7 +1,9 @@
 package Complete::Util;
 
-our $DATE = '2019-12-15'; # DATE
-our $VERSION = '0.605'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-12-20'; # DATE
+our $DIST = 'Complete-Util'; # DIST
+our $VERSION = '0.606'; # VERSION
 
 use 5.010001;
 use strict;
@@ -794,12 +796,24 @@ sub modify_answer {
     my $words = ref($answer) eq 'HASH' ? $answer->{words} : $answer;
 
     if (defined(my $prefix = $args{prefix})) {
-        $_ = "$prefix$_" for @$words;
+        for (@$words) {
+            if (ref $_ eq 'HASH') {
+                $_->{word} = "$prefix$_->{word}";
+            } else {
+                $_ = "$prefix$_";
+            }
+        }
     }
     if (defined(my $suffix = $args{suffix})) {
-        $_ = "$_$suffix" for @$words;
+        for (@$words) {
+            if (ref $_ eq 'HASH') {
+                $_->{word} = "$_->{word}$suffix";
+            } else {
+                $_ = "$_$suffix";
+            }
+        }
     }
-    undef;
+    $answer;
 }
 
 $SPEC{ununiquify_answer} = {
@@ -850,7 +864,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.605 of Complete::Util (from Perl distribution Complete-Util), released on 2019-12-15.
+This document describes version 0.606 of Complete::Util (from Perl distribution Complete-Util), released on 2019-12-20.
 
 =head1 DESCRIPTION
 
@@ -1251,9 +1265,10 @@ After Text::Levenshtein::Flexible is installed:
 
 =head1 ENVIRONMENT
 
-=head2 COMPLETE_UTIL_TRACE => bool
+=head2 COMPLETE_UTIL_TRACE
 
-If set to true, will display more log statements for debugging.
+Bool. If set to true, will generate more log statements for debugging (at the
+trace level).
 
 =head2 COMPLETE_UTIL_LEVENSHTEIN => str ('pp'|'xs'|'flexible')
 
